==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/outputs/GetEventGridDataConnectionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress

/**
 * Class representing an Event Grid data connection.
 * @property blobStorageEventType The name of blob storage event type to process.
 * @property consumerGroup The event hub consumer group.
 * @property dataFormat The data format of the message. Optionally the data format can be added to each message.
 * @property databaseRouting Indication for database routing information from the data connection, by default only database routing information is allowed
 * @property eventGridResourceId The resource ID of the event grid that is subscribed to the storage account events.
 * @property eventHubResourceId The resource ID where the event grid is configured to send events.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property ignoreFirstRecord A Boolean value that, if set to true, indicates that ingestion should ignore the first record of every file
 * @property kind Kind of the endpoint for the data connection
 * Expected value is 'EventGrid'.
 * @property location Resource location.
 * @property managedIdentityObjectId The object ID of managedIdentityResourceId
 * @property managedIdentityResourceId The resource ID of a managed identity (system or user assigned) to be used to authenticate with event hub and storage account.
 * @property mappingRuleName The mapping rule to be used to ingest the data. Optionally the mapping information can be added to each message.
 * @property name The name of the resource
 * @property provisioningState The provisioned state of the resource.
 * @property storageAccountResourceId The resource ID of the storage account where the data resides.
 * @property tableName The table where the data should be ingested. Optionally the table information can be added to each message.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetEventGridDataConnectionResult(
    public val blobStorageEventType: String? = null,
    public val consumerGroup: String,
    public val dataFormat: String? = null,
    public val databaseRouting: String? = null,
    public val eventGridResourceId: String? = null,
    public val eventHubResourceId: String,
    public val id: String,
    public val ignoreFirstRecord: Boolean? = null,
    public val kind: String,
    public val location: String? = null,
    public val managedIdentityObjectId: String,
    public val managedIdentityResourceId: String? = null,
    public val mappingRuleName: String? = null,
    public val name: String,
    public val provisioningState: String,
    public val storageAccountResourceId: String,
    public val tableName: String? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.kusto.outputs.GetEventGridDataConnectionResult):
            GetEventGridDataConnectionResult = GetEventGridDataConnectionResult(
            blobStorageEventType = javaType.blobStorageEventType().map({ args0 -> args0 }).orElse(null),
            consumerGroup = javaType.consumerGroup(),
            dataFormat = javaType.dataFormat().map({ args0 -> args0 }).orElse(null),
            databaseRouting = javaType.databaseRouting().map({ args0 -> args0 }).orElse(null),
            eventGridResourceId = javaType.eventGridResourceId().map({ args0 -> args0 }).orElse(null),
            eventHubResourceId = javaType.eventHubResourceId(),
            id = javaType.id(),
            ignoreFirstRecord = javaType.ignoreFirstRecord().map({ args0 -> args0 }).orElse(null),
            kind = javaType.kind(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            managedIdentityObjectId = javaType.managedIdentityObjectId(),
            managedIdentityResourceId = javaType.managedIdentityResourceId().map({ args0 ->
                args0
            }).orElse(null),
            mappingRuleName = javaType.mappingRuleName().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            storageAccountResourceId = javaType.storageAccountResourceId(),
            tableName = javaType.tableName().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/outputs/GetEventGridDataConnectionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress

/**
 * Class representing an Event Grid data connection.
 * @property blobStorageEventType The name of blob storage event type to process.
 * @property consumerGroup The event hub consumer group.
 * @property dataFormat The data format of the message. Optionally the data format can be added to each message.
 * @property databaseRouting Indication for database routing information from the data connection, by default only database routing information is allowed
 * @property eventGridResourceId The resource ID of the event grid that is subscribed to the storage account events.
 * @property eventHubResourceId The resource ID where the event grid is configured to send events.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property ignoreFirstRecord A Boolean value that, if set to true, indicates that ingestion should ignore the first record of every file
 * @property kind Kind of the endpoint for the data connection
 * Expected value is 'EventGrid'.
 * @property location Resource location.
 * @property managedIdentityObjectId The object ID of managedIdentityResourceId
 * @property managedIdentityResourceId The resource ID of a managed identity (system or user assigned) to be used to authenticate with event hub and storage account.
 * @property mappingRuleName The mapping rule to be used to ingest the data. Optionally the mapping information can be added to each message.
 * @property name The name of the resource
 * @property provisioningState The provisioned state of the resource.
 * @property storageAccountResourceId The resource ID of the storage account where the data resides.
 * @property tableName The table where the data should be ingested. Optionally the table information can be added to each message.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetEventGridDataConnectionResult(
    public val blobStorageEventType: String? = null,
    public val consumerGroup: String,
    public val dataFormat: String? = null,
    public val databaseRouting: String? = null,
    public val eventGridResourceId: String? = null,
    public val eventHubResourceId: String,
    public val id: String,
    public val ignoreFirstRecord: Boolean? = null,
    public val kind: String,
    public val location: String? = null,
    public val managedIdentityObjectId: String,
    public val managedIdentityResourceId: String? = null,
    public val mappingRuleName: String? = null,
    public val name: String,
    public val provisioningState: String,
    public val storageAccountResourceId: String,
    public val tableName: String? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.kusto.outputs.GetEventGridDataConnectionResult): GetEventGridDataConnectionResult = GetEventGridDataConnectionResult(
            blobStorageEventType = javaType.blobStorageEventType().map({ args0 -> args0 }).orElse(null),
            consumerGroup = javaType.consumerGroup(),
            dataFormat = javaType.dataFormat().map({ args0 -> args0 }).orElse(null),
            databaseRouting = javaType.databaseRouting().map({ args0 -> args0 }).orElse(null),
            eventGridResourceId = javaType.eventGridResourceId().map({ args0 -> args0 }).orElse(null),
            eventHubResourceId = javaType.eventHubResourceId(),
            id = javaType.id(),
            ignoreFirstRecord = javaType.ignoreFirstRecord().map({ args0 -> args0 }).orElse(null),
            kind = javaType.kind(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            managedIdentityObjectId = javaType.managedIdentityObjectId(),
            managedIdentityResourceId = javaType.managedIdentityResourceId().map({ args0 ->
                args0
            }).orElse(null),
            mappingRuleName = javaType.mappingRuleName().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            storageAccountResourceId = javaType.storageAccountResourceId(),
            tableName = javaType.tableName().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
        )
    }
}
